@@ -1,6 +1,6 @@
 from uuid import uuid4
 
-from flask import Blueprint, current_app, g, redirect, request
+from flask import Blueprint, current_app, g, redirect, request, jsonify
 from rq import Connection, Queue
 
 from .build import build
@@ -29,14 +29,16 @@ def get_redis():
     return g.redis
 
 
-@bp.route("/latest")
-def api_latest():
-    return redirect("/json/latest.json")
-
-
+# legacy
 @bp.route("/branches")
 def api_branches():
-    return redirect("/json/branches.json")
+    return redirect("/json/v1/branches.json")
+
+
+# tbd
+@bp.route("/latest")
+def api_latest():
+    return redirect("/json/v1/latest.json")
 
 
 def get_queue() -> Queue:
@@ -89,6 +91,7 @@ def validate_packages(req):
         return (
             {
                 "detail": f"Unsupported package(s): {', '.join(unknown_packages)}",
+                "status": 422,
             },
             422,
         )
@@ -110,9 +113,7 @@ def validate_request(req):
     req["distro"] = req.get("distro", "openwrt")
     if req["distro"] not in get_distros():
         return (
-            {
-                "detail": f"Unsupported distro: {req['distro']}",
-            },
+            {"detail": f"Unsupported distro: {req['distro']}", "status": 400},
             400,
         )
 
@@ -127,17 +128,13 @@ def validate_request(req):
 
     if req["branch"] not in current_app.config["BRANCHES"].keys():
         return (
-            {
-                "detail": f"Unsupported branch: {req['version']}",
-            },
+            {"detail": f"Unsupported branch: {req['version']}", "status": 400},
             400,
         )
 
     if req["version"] not in current_app.config["BRANCHES"][req["branch"]]["versions"]:
         return (
-            {
-                "detail": f"Unsupported version: {req['version']}",
-            },
+            {"detail": f"Unsupported version: {req['version']}", "status": 400},
             400,
         )
 
@@ -150,9 +147,7 @@ def validate_request(req):
         req["target"],
     ):
         return (
-            {
-                "detail": f"Unsupported target: {req['target']}",
-            },
+            {"detail": f"Unsupported target: {req['target']}", "status": 400},
             400,
         )
 
@@ -179,9 +174,7 @@ def validate_request(req):
             req["profile"],
         ):
             return (
-                {
-                    "detail": f"Unsupported profile: {req['profile']}",
-                },
+                {"detail": f"Unsupported profile: {req['profile']}", "status": 400},
                 400,
             )
 
@@ -206,15 +199,13 @@ def return_job(job):
         response.update(job.meta)
 
     if job.is_failed:
-        response.update(
-            {"status": 500, "details": job.exc_info.strip().split("\n")[-1]}
-        )
+        response.update({"status": 500, "detail": job.exc_info.strip().split("\n")[-1]})
 
     elif job.is_queued:
         response.update(
             {
                 "status": 202,
-                "details": job.get_status(),
+                "detail": "queued",
                 "queue_position": job.get_position() or 0,
             }
         )
@@ -224,7 +215,7 @@ def return_job(job):
         response.update(
             {
                 "status": 202,
-                "details": job.get_status(),
+                "detail": "started",
             }
         )
 
@@ -238,6 +229,10 @@ def return_job(job):
     return response, response["status"], headers
 
 
+def api_v1_overview():
+    return jsonify(current_app.config["OVERVIEW"])
+
+
 def api_build_get(request_hash):
     return api_v1_build_get(request_hash)
 
